@@ -1,6 +1,6 @@
 package Plagger;
 use strict;
-our $VERSION = '0.6.5';
+our $VERSION = '0.6.6';
 
 use 5.8.1;
 use Carp;
@@ -23,12 +23,6 @@ use Plagger::Subscription;
 use Plagger::Template;
 use Plagger::Update;
 
-sub active_hooks {
-    my $self = shift;
-    my @hooks= keys %{$self->{hooks}};
-    wantarray ? @hooks : \@hooks;
-}
-
 sub context { undef }
 
 sub bootstrap {
@@ -81,7 +75,7 @@ sub rewrite_config {
     # xxx this is a quick hack: It should be a YAML roundtrip maybe
     for my $task (@{ $self->{rewrite_tasks} }) {
         my($key, $old_value, $new_value ) = @$task;
-        if ($data =~ s/^(\s+$key:\s+)$old_value\s*$/$1$new_value/m) {
+        if ($data =~ s/^(\s+$key:\s+)$old_value[ \t]*$/$1$new_value/m) {
             $count++;
         } else {
             $self->log(error => "$key: $old_value not found in $self->{config_path}");
@@ -156,18 +150,25 @@ sub load_plugins {
 
     if ($self->conf->{plugin_path}) {
         for my $path (@{ $self->conf->{plugin_path} }) {
-            my $rule = File::Find::Rule->new;
-               $rule->file;
-               $rule->name( qr/^\w[\w\.]*$/ );
-            my @files = $rule->in($path);
-
-            for my $file (@files) {
-                next if $file =~ /\W(?:\.svn|CVS)\b/;
-                my $pkg = $self->extract_package($file)
-                    or die "Can't find package from $file";
-
-                (my $base = $file) =~ s!^$path/!!;
-                $self->plugins_path->{$pkg} = $file;
+            opendir my $dir, $path or do {
+                $self->log(warn => "$path: $!");
+                next;
+            };
+            while (my $ent = readdir $dir) {
+                next if $ent =~ /^\./;
+                $ent = File::Spec->catfile($path, $ent);
+                if (-f $ent && $ent =~ /\.pm$/) {
+                    my $pkg = $self->extract_package($ent)
+                        or die "Can't find package from $ent";
+                    (my $base = $ent) =~ s!^$path/!!;
+                    $self->plugins_path->{$pkg} = $ent;
+                } elsif (-d $ent) {
+                    my $lib = File::Spec->catfile($ent, "lib");
+                    if (-e $lib && -d _) {
+                        $self->log(debug => "Add $lib to INC path");
+                        unshift @INC, $lib;
+                    }
+                }
             }
         }
     }
@@ -282,6 +283,7 @@ sub run {
             my $ok = $self->run_hook_once('customfeed.handle', { feed => $feed });
             if (!$ok) {
                 Plagger->context->log(error => $feed->url . " is not aggregated by any aggregator");
+                Plagger->context->subscription->delete_feed($feed);
             }
         }
     }
